Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2331)

Unified Diff: ash/common/system/chromeos/network/network_list_md.h

Issue 2698473007: Convert path usage in NetworkListViewBase subclasses to use guids. (Closed)
Patch Set: Tweak NetworkPortalNotificationControllerTest to create GUIDs for new NetworkStates. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/system/chromeos/network/network_list_md.h
diff --git a/ash/common/system/chromeos/network/network_list_md.h b/ash/common/system/chromeos/network/network_list_md.h
index d99243a898a2fe35a1287a51ba79194079580c40..91803817cc9ac36ae68b8d57b2ebbd0325a04c83 100644
--- a/ash/common/system/chromeos/network/network_list_md.h
+++ b/ash/common/system/chromeos/network/network_list_md.h
@@ -42,8 +42,7 @@ class NetworkListViewMd : public NetworkListViewBase,
// NetworkListViewBase:
void Update() override;
- bool IsNetworkEntry(views::View* view,
- std::string* service_path) const override;
+ bool IsNetworkEntry(views::View* view, std::string* guid) const override;
private:
// Clears |network_list_| and adds to it |networks| that match |delegate_|'s
@@ -60,17 +59,17 @@ class NetworkListViewMd : public NetworkListViewBase,
void OrderNetworks();
// Refreshes a list of child views, updates |network_map_| and
// |service_path_map_| and performs layout making sure selected view if any is
// scrolled into view.
void UpdateNetworkListInternal();
// Adds new or updates existing child views including header row and messages.
- // Returns a set of service paths for the added network connections.
+ // Returns a set of guids for the added network connections.
std::unique_ptr<std::set<std::string>> UpdateNetworkListEntries();
// Adds or updates child views representing the network connections when
// |is_wifi| is matching the attribute of a network connection starting at
- // |child_index|. Returns a set of service paths for the added network
+ // |child_index|. Returns a set of guids for the added network
// connections.
std::unique_ptr<std::set<std::string>> UpdateNetworkChildren(
NetworkInfo::Type type,
@@ -119,9 +118,9 @@ class NetworkListViewMd : public NetworkListViewBase,
using NetworkMap = std::map<views::View*, std::string>;
NetworkMap network_map_;
- // A map of network service paths to their view.
- typedef std::map<std::string, views::View*> ServicePathMap;
- ServicePathMap service_path_map_;
+ // A map of network guids to their view.
+ typedef std::map<std::string, views::View*> NetworkGuidMap;
+ NetworkGuidMap network_guid_map_;
DISALLOW_COPY_AND_ASSIGN(NetworkListViewMd);
};
« no previous file with comments | « ash/common/system/chromeos/network/network_list.cc ('k') | ash/common/system/chromeos/network/network_list_md.cc » ('j') | no next file with comments »
@@ -60,17 +59,17 @@ class NetworkListViewMd : public NetworkListViewBase,
void OrderNetworks();
// Refreshes a list of child views, updates |network_map_| and
- // |service_path_map_| and performs layout making sure selected view if any is
+ // |network_guid_map_| and performs layout making sure selected view if any is
// scrolled into view.
void UpdateNetworkListInternal();

Powered by Google App Engine
This is Rietveld 408576698